@@ -1,4 +1,4 @@
-# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2018-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the 'License'). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,9 +10,10 @@
 # distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-JSON = 'application/json'
+"""This module contains constants that define MIME content types."""
+JSON = "application/json"
 CSV = "text/csv"
 OCTET_STREAM = "application/octet-stream"
-ANY = '*/*'
-NPY = 'application/x-npy'
+ANY = "*/*"
+NPY = "application/x-npy"
 UTF8_TYPES = [JSON, CSV]
